@@ -3,14 +3,13 @@ use warnings;
 
 package JIRA::Client;
 {
-  $JIRA::Client::VERSION = '0.39';
+  $JIRA::Client::VERSION = '0.41';
 }
 # ABSTRACT: An extended interface to JIRA's SOAP API.
 
 use Carp;
 use Data::Util qw(:check);
 use SOAP::Lite;
-use URI;
 
 
 sub new {
@@ -40,8 +39,9 @@ sub new {
 
     $args->{wsdl} = '/rpc/soap/jirasoapservice-v2?wsdl' unless exists $args->{wsdl};
 
-    my $url = URI->new($args->{baseurl});
-    $url->path_query($args->{wsdl});
+    my $url = $args->{baseurl};
+    $url =~ s{/$}{}; # clean trailing slash
+    $url .= $args->{wsdl};
 
     my $soap = SOAP::Lite->proxy($url, @{$args->{soapargs}});
 
@@ -661,36 +661,38 @@ sub attach_strings_to_issue {
 }
 
 
-sub filter_issues {
+sub filter_issues_unsorted {
     my ($self, $filter, $limit) = @_;
 
     $filter =~ s/^\s*"?//;
     $filter =~ s/"?\s*$//;
 
-    my $issues = do {
-	if ($filter =~ /^(?:[A-Z]+-\d+\s+)*[A-Z]+-\d+$/i) {
-	    # space separated key list
-	    [map {$self->getIssue(uc $_)} split / /, $filter];
-	} elsif ($filter =~ /^[\w-]+$/i) {
-	    # saved filter
-	    $self->getIssuesFromFilterWithLimit($filter, 0, $limit || 1000);
-	} else {
-	    # JQL filter
-	    $self->getIssuesFromJqlSearch($filter, $limit || 1000);
-	}
-    };
+    if ($filter =~ /^(?:[A-Z]+-\d+\s+)*[A-Z]+-\d+$/i) {
+        # space separated key list
+        return map {$self->getIssue(uc $_)} split / /, $filter;
+    } elsif ($filter =~ /^[\w-]+$/i) {
+        # saved filter
+        return @{$self->getIssuesFromFilterWithLimit($filter, 0, $limit || 1000)};
+    } else {
+        # JQL filter
+        return @{$self->getIssuesFromJqlSearch($filter, $limit || 1000)};
+    }
+}
 
+
+sub filter_issues {
     # Order the issues by project key and then by numeric value using
     # a Schwartzian transform.
     map  {$_->[2]}
 	sort {$a->[0] cmp $b->[0] or $a->[1] <=> $b->[1]}
-	    map  {my ($p, $n) = ($_->{key} =~ /([A-Z]+)-(\d+)/); [$p, $n, $_]} @$issues;
+	    map  {my ($p, $n) = ($_->{key} =~ /([A-Z]+)-(\d+)/); [$p, $n, $_]}
+                filter_issues_unsorted(@_);
 }
 
 
 package RemoteFieldValue;
 {
-  $RemoteFieldValue::VERSION = '0.39';
+  $RemoteFieldValue::VERSION = '0.41';
 }
 
 sub new {
@@ -706,7 +708,7 @@ sub new {
 
 package RemoteCustomFieldValue;
 {
-  $RemoteCustomFieldValue::VERSION = '0.39';
+  $RemoteCustomFieldValue::VERSION = '0.41';
 }
 
 sub new {
@@ -719,7 +721,7 @@ sub new {
 
 package RemoteComponent;
 {
-  $RemoteComponent::VERSION = '0.39';
+  $RemoteComponent::VERSION = '0.41';
 }
 
 sub new {
@@ -732,7 +734,7 @@ sub new {
 
 package RemoteVersion;
 {
-  $RemoteVersion::VERSION = '0.39';
+  $RemoteVersion::VERSION = '0.41';
 }
 
 sub new {
@@ -969,15 +971,18 @@ sub AUTOLOAD {
 1; # End of JIRA::Client
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 JIRA::Client - An extended interface to JIRA's SOAP API.
 
 =head1 VERSION
 
-version 0.39
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -1069,9 +1074,10 @@ distinguish them and we can avoid future name clashes.
 =head2 B<new> BASEURL, USER, PASSWD [, <SOAP::Lite arguments>]
 
 C<BASEURL> is the JIRA server's base URL (e.g.,
-C<https://jira.example.net/>), to which the default WSDL descriptor
-path (C</rpc/soap/jirasoapservice-v2?wsdl>) will be appended in order
-to construct the underlying SOAP::Lite object.
+C<https://jira.example.net> or C<https://example.net/jira>), to which
+the default WSDL descriptor path
+(C</rpc/soap/jirasoapservice-v2?wsdl>) will be appended in order to
+construct the underlying SOAP::Lite object.
 
 C<USER> and C<PASSWD> are the credentials that will be used to
 authenticate into JIRA.
@@ -1381,7 +1387,7 @@ file names and the values their contents.
 The method retuns the value returned by the
 B<addBase64EncodedAttachmentsToIssue> API method.
 
-=head2 B<filter_issues> FILTER [, LIMIT]
+=head2 B<filter_issues_unsorted> FILTER [, LIMIT]
 
 This method returns a list of RemoteIssue objects from the specified
 FILTER, which is a string that is understood in one of these ways (in
@@ -1422,7 +1428,10 @@ beings to request a list of issues. Be warned, however, that you are
 responsible to de-taint the FILTER argument before passing it to the
 method.
 
-The returned list of RemoteIssue objects is sorted by issue key.
+=head2 B<filter_issues> FILTER [, LIMIT]
+
+This method invokes the B<filter_issues_unsorted> method with the same
+arguments and returns the list of RemoteIssue objects sorted by issue key.
 
 =head1 OTHER CONSTRUCTORS
 
@@ -1479,10 +1488,9 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by CPqD.
+This software is copyright (c) 2014 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
